@@ -1,6 +1,7 @@
 # coding: utf-8
 
 from xml.dom import Node
+import xml.sax.saxutils as SU
 
 def getChildElementsByTagName(node, tagName):
     children = node.childNodes
@@ -11,3 +12,6 @@ def getChildElementsByTagName(node, tagName):
             elems.append(child)
     return elems
 
+def escape(string):
+    return (SU.escape(string)).replace(u"\"", u"&quot;")
+
